Enum MultisigMemberSignature
#[non_exhaustive]pub enum MultisigMemberSignature {
Ed25519(Ed25519Signature),
Secp256k1(Secp256k1Signature),
Secp256r1(Secp256r1Signature),
Passkey(PasskeyAuthenticator),
}Expand description
A signature from a member of a multisig committee.
BCS
The BCS serialized form for this type is defined by the following ABNF:
multisig-member-signature = ed25519-multisig-member-signature /
secp256k1-multisig-member-signature /
secp256r1-multisig-member-signature /
passkey-multisig-member-signature
ed25519-multisig-member-signature = %d00 ed25519-signature
secp256k1-multisig-member-signature = %d01 secp256k1-signature
secp256r1-multisig-member-signature = %d02 secp256r1-signature
passkey-multisig-member-signature = %d04 passkey-authenticatorVariants (Non-exhaustive)
This enum is marked as non-exhaustive
Ed25519(Ed25519Signature)
Secp256k1(Secp256k1Signature)
Secp256r1(Secp256r1Signature)
Passkey(PasskeyAuthenticator)
Implementations
impl MultisigMemberSignature
impl MultisigMemberSignature
pub fn is_ed25519(&self) -> bool
pub fn is_ed25519(&self) -> bool
Checks if this is a ed25519 variant.
pub fn as_ed25519(&self) -> &Ed25519Signature
pub fn as_ed25519(&self) -> &Ed25519Signature
Converts this into a ed25519 if it is a ed25519 variant, or panics otherwise.
pub fn as_ed25519_mut(&mut self) -> &mut Ed25519Signature
pub fn as_ed25519_mut(&mut self) -> &mut Ed25519Signature
Converts this into a mut ed25519 if it is a ed25519 variant, or panics otherwise.
pub fn as_ed25519_opt(&self) -> Option<&Ed25519Signature>
pub fn as_ed25519_opt(&self) -> Option<&Ed25519Signature>
Converts this into a ed25519 if it is a ed25519 variant, or returns None otherwise.
pub fn as_ed25519_mut_opt(&mut self) -> Option<&mut Ed25519Signature>
pub fn as_ed25519_mut_opt(&mut self) -> Option<&mut Ed25519Signature>
Converts this into a mut ed25519 if it is a ed25519 variant, or returns None otherwise.
pub fn into_ed25519_opt(self) -> Option<Ed25519Signature>
pub fn into_ed25519_opt(self) -> Option<Ed25519Signature>
Converts this into a ed25519 if it is a ed25519 variant, or returns None otherwise.
pub fn into_ed25519(self) -> Ed25519Signature
pub fn into_ed25519(self) -> Ed25519Signature
Converts this into a ed25519 if it is a ed25519 variant, or panics otherwise.
pub fn is_secp256k1(&self) -> bool
pub fn is_secp256k1(&self) -> bool
Checks if this is a secp256k1 variant.
pub fn as_secp256k1(&self) -> &Secp256k1Signature
pub fn as_secp256k1(&self) -> &Secp256k1Signature
Converts this into a secp256k1 if it is a secp256k1 variant, or panics otherwise.
pub fn as_secp256k1_mut(&mut self) -> &mut Secp256k1Signature
pub fn as_secp256k1_mut(&mut self) -> &mut Secp256k1Signature
Converts this into a mut secp256k1 if it is a secp256k1 variant, or panics otherwise.
pub fn as_secp256k1_opt(&self) -> Option<&Secp256k1Signature>
pub fn as_secp256k1_opt(&self) -> Option<&Secp256k1Signature>
Converts this into a secp256k1 if it is a secp256k1 variant, or returns None otherwise.
pub fn as_secp256k1_mut_opt(&mut self) -> Option<&mut Secp256k1Signature>
pub fn as_secp256k1_mut_opt(&mut self) -> Option<&mut Secp256k1Signature>
Converts this into a mut secp256k1 if it is a secp256k1 variant, or returns None otherwise.
pub fn into_secp256k1_opt(self) -> Option<Secp256k1Signature>
pub fn into_secp256k1_opt(self) -> Option<Secp256k1Signature>
Converts this into a secp256k1 if it is a secp256k1 variant, or returns None otherwise.
pub fn into_secp256k1(self) -> Secp256k1Signature
pub fn into_secp256k1(self) -> Secp256k1Signature
Converts this into a secp256k1 if it is a secp256k1 variant, or panics otherwise.
pub fn is_secp256r1(&self) -> bool
pub fn is_secp256r1(&self) -> bool
Checks if this is a secp256r1 variant.
pub fn as_secp256r1(&self) -> &Secp256r1Signature
pub fn as_secp256r1(&self) -> &Secp256r1Signature
Converts this into a secp256r1 if it is a secp256r1 variant, or panics otherwise.
pub fn as_secp256r1_mut(&mut self) -> &mut Secp256r1Signature
pub fn as_secp256r1_mut(&mut self) -> &mut Secp256r1Signature
Converts this into a mut secp256r1 if it is a secp256r1 variant, or panics otherwise.
pub fn as_secp256r1_opt(&self) -> Option<&Secp256r1Signature>
pub fn as_secp256r1_opt(&self) -> Option<&Secp256r1Signature>
Converts this into a secp256r1 if it is a secp256r1 variant, or returns None otherwise.
pub fn as_secp256r1_mut_opt(&mut self) -> Option<&mut Secp256r1Signature>
pub fn as_secp256r1_mut_opt(&mut self) -> Option<&mut Secp256r1Signature>
Converts this into a mut secp256r1 if it is a secp256r1 variant, or returns None otherwise.
pub fn into_secp256r1_opt(self) -> Option<Secp256r1Signature>
pub fn into_secp256r1_opt(self) -> Option<Secp256r1Signature>
Converts this into a secp256r1 if it is a secp256r1 variant, or returns None otherwise.
pub fn into_secp256r1(self) -> Secp256r1Signature
pub fn into_secp256r1(self) -> Secp256r1Signature
Converts this into a secp256r1 if it is a secp256r1 variant, or panics otherwise.
pub fn is_passkey(&self) -> bool
pub fn is_passkey(&self) -> bool
Checks if this is a passkey variant.
pub fn as_passkey(&self) -> &PasskeyAuthenticator
pub fn as_passkey(&self) -> &PasskeyAuthenticator
Converts this into a passkey if it is a passkey variant, or panics otherwise.
pub fn as_passkey_mut(&mut self) -> &mut PasskeyAuthenticator
pub fn as_passkey_mut(&mut self) -> &mut PasskeyAuthenticator
Converts this into a mut passkey if it is a passkey variant, or panics otherwise.
pub fn as_passkey_opt(&self) -> Option<&PasskeyAuthenticator>
pub fn as_passkey_opt(&self) -> Option<&PasskeyAuthenticator>
Converts this into a passkey if it is a passkey variant, or returns None otherwise.
pub fn as_passkey_mut_opt(&mut self) -> Option<&mut PasskeyAuthenticator>
pub fn as_passkey_mut_opt(&mut self) -> Option<&mut PasskeyAuthenticator>
Converts this into a mut passkey if it is a passkey variant, or returns None otherwise.
pub fn into_passkey_opt(self) -> Option<PasskeyAuthenticator>
pub fn into_passkey_opt(self) -> Option<PasskeyAuthenticator>
Converts this into a passkey if it is a passkey variant, or returns None otherwise.
pub fn into_passkey(self) -> PasskeyAuthenticator
pub fn into_passkey(self) -> PasskeyAuthenticator
Converts this into a passkey if it is a passkey variant, or panics otherwise.
pub fn scheme(&self) -> SignatureScheme
impl MultisigMemberSignature
impl MultisigMemberSignature
pub fn to_base64(&self) -> String
pub fn from_base64(s: &str) -> Result<MultisigMemberSignature, MultisigError>